@@ -1,21 +1,18 @@
-import tarfile
+import subprocess
 
 import requests
 
 
 def create_archive(path, tag):
-    """
-    create the artifact to upload to Heroku Source API
+    """ create the artifact to upload to Heroku Source API """
 
-    Notes:
-        - recursive=True is the default
-        - consult tar.add() filter kwarg for excluding files and paths
-    """
     name = f"source_blob_{tag}.tar.gz"
 
-    with tarfile.open(name=name, mode="x:gz") as tar:
-        tar.add(path, recursive=True, arcname=".")
+    print("Zipping the project...")
+    subprocess.run(["git", "archive", "-o", name, "HEAD"])
 
+    print("Done!")
+    print()
     return name
 
 
@@ -37,9 +34,12 @@ def create_source_blob(base_url, headers, base_dir, project_name, version):
 
     source_blob_filename = create_archive(base_dir, version)
 
+    print("Uploading zipped project...")
     res = requests.put(
         put_url, headers={"Content-Type": ""}, data=open(source_blob_filename, "rb")
     )
     res.raise_for_status()
 
+    print("Done!")
+    print()
     return get_url
